#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const yargs_1 = tslib_1.__importDefault(require("yargs"));
const commands_1 = require("@graphql-inspector/commands");
const loaders_1 = require("@graphql-inspector/loaders");
function main() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const config = {
            loaders: ['code', 'git', 'github', 'graphql', 'json', 'url'],
            commands: ['docs', 'serve', 'diff', 'validate', 'coverage', 'introspect', 'similar', 'audit'],
        };
        const loaders = (0, loaders_1.useLoaders)(config);
        const commands = (0, commands_1.useCommands)({ config, loaders });
        const root = yargs_1.default
            .scriptName('graphql-inspector')
            .detectLocale(false)
            .epilog('Visit https://graphql-inspector.com for more information')
            .version()
            .options({
            r: {
                alias: 'require',
                describe: 'Require modules',
                type: 'array',
            },
            t: {
                alias: 'token',
                describe: 'Access Token',
                type: 'string',
            },
            h: {
                alias: 'header',
                describe: 'Http Header',
                type: 'array',
            },
            hl: {
                alias: 'left-header',
                describe: 'Http Header - Left',
                type: 'array',
            },
            hr: {
                alias: 'right-header',
                describe: 'Http Header - Right',
                type: 'array',
            },
        });
        // eslint-disable-next-line @typescript-eslint/no-unused-expressions
        commands
            .reduce((cli, cmd) => cli.command(cmd), root)
            .help()
            .showHelpOnFail(false).argv;
    });
}
main();
